@@ -40,13 +40,13 @@ on how the various constants and lists look like.
 
 NICAM 728 32-kHz, 14-bit digital stereo audio is transmitted in 1ms frames
 containing 8 bits frame sync, 5 bits control, 11 bits additional data,
-and 704 bits audio data.  The bit rate is reduced by transmitting only
+and 704 bits audio data. The bit rate is reduced by transmitting only
 10 bits plus parity of each 14 bit sample, the largest sample in a frame
-determines which 10 bits are transmitted.  The parity bits for audio
+determines which 10 bits are transmitted. The parity bits for audio
 samples also specify the scaling factor used for that channel during that
-frame.  The companeded audio data is interleaved to reduce the influence
+frame. The companded audio data is interleaved to reduce the influence
 of dropouts and the whole frame except for sync bits is scrambled for
-spectrum shaping.  Data is modulated using QPSK, at below following
+spectrum shaping. Data is modulated using QPSK, at below following
 subcarrier freqs
 
 =head1 Broadcast Format by Country
@@ -119,7 +119,7 @@ Republic, Ukraine, Vietnam
 
 =item (G) SECAM
 
-Greecem Iran, Iraq, Mali, Mauritus, Morocco, Saudi Arabia
+Greece, Iran, Iraq, Mali, Mauritus, Morocco, Saudi Arabia
 
 =item (K) SECAM
 
@@ -173,7 +173,7 @@ $CHANLIST{"ntsc-bcast"} contains a reference to %NTSC_BCAST.
 =head1 AUTHOR
 
 Nathan Laredo (laredo@broked.net), adapted to perl by Marc Lehmann
-<pcg@goof.com>
+<schmorp@schmorp.de>
 
 =cut
 
